## 📚 Official Cookbook

Looking for examples and guides? Then head over to the official ScrapeGraph SDK [Cookbook](https://github.com/ScrapeGraphAI/scrapegraph-sdk/tree/main/cookbook)!

The cookbook provides step-by-step instructions, practical examples, and tips to help you get started and make the most out of ScrapeGraph SDK.

You will find some colab notebooks with our partners as well, such as Langchain 🦜 and LlamaIndex 🦙

Happy scraping! 🚀
